/* small-set.c generated by valac 0.21.1.1-0d6f, the Vala compiler
 * generated from small-set.vala, do not modify */

/*
 * Copyright © 2013 Intel Corporation
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Simon McVittie <simon.mcvittie@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <folks/small-set.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/small-set-internal.h>


#define TYPE_DIRECT_EQ (direct_eq_get_type ())
#define DIRECT_EQ(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DIRECT_EQ, DirectEq))
#define DIRECT_EQ_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DIRECT_EQ, DirectEqClass))
#define IS_DIRECT_EQ(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DIRECT_EQ))
#define IS_DIRECT_EQ_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DIRECT_EQ))
#define DIRECT_EQ_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DIRECT_EQ, DirectEqClass))

typedef struct _DirectEq DirectEq;
typedef struct _DirectEqClass DirectEqClass;
typedef struct _DirectEqPrivate DirectEqPrivate;

#define TYPE_UINT (uint_get_type ())
#define UINT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_UINT, UInt))
#define UINT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_UINT, UIntClass))
#define IS_UINT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_UINT))
#define IS_UINT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_UINT))
#define UINT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_UINT, UIntClass))

typedef struct _UInt UInt;
typedef struct _UIntClass UIntClass;
typedef struct _UIntPrivate UIntPrivate;

#define TYPE_SMALL_SET_TESTS (small_set_tests_get_type ())
#define SMALL_SET_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SMALL_SET_TESTS, SmallSetTests))
#define SMALL_SET_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SMALL_SET_TESTS, SmallSetTestsClass))
#define IS_SMALL_SET_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SMALL_SET_TESTS))
#define IS_SMALL_SET_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SMALL_SET_TESTS))
#define SMALL_SET_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SMALL_SET_TESTS, SmallSetTestsClass))

typedef struct _SmallSetTests SmallSetTests;
typedef struct _SmallSetTestsClass SmallSetTestsClass;
typedef struct _SmallSetTestsPrivate SmallSetTestsPrivate;
typedef struct _Block1Data Block1Data;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _DirectEq {
	GObject parent_instance;
	DirectEqPrivate * priv;
	guint u;
};

struct _DirectEqClass {
	GObjectClass parent_class;
};

struct _UInt {
	GObject parent_instance;
	UIntPrivate * priv;
	guint u;
};

struct _UIntClass {
	GObjectClass parent_class;
};

struct _SmallSetTests {
	FolksTestCase parent_instance;
	SmallSetTestsPrivate * priv;
};

struct _SmallSetTestsClass {
	FolksTestCaseClass parent_class;
};

struct _Block1Data {
	int _ref_count_;
	SmallSetTests * self;
	guint sum;
	UInt* ten;
};

struct _Block2Data {
	int _ref_count_;
	SmallSetTests * self;
	guint sum;
};

struct _Block3Data {
	int _ref_count_;
	SmallSetTests * self;
	guint u;
};

struct _Block4Data {
	int _ref_count_;
	SmallSetTests * self;
	FolksSmallSet* small;
	gint i;
};


static gpointer direct_eq_parent_class = NULL;
static gpointer uint_parent_class = NULL;
static gpointer small_set_tests_parent_class = NULL;

GType direct_eq_get_type (void) G_GNUC_CONST;
enum  {
	DIRECT_EQ_DUMMY_PROPERTY
};
DirectEq* direct_eq_new (guint u);
DirectEq* direct_eq_construct (GType object_type, guint u);
static void direct_eq_finalize (GObject* obj);
GType uint_get_type (void) G_GNUC_CONST;
enum  {
	UINT_DUMMY_PROPERTY
};
UInt* uint_new (guint u);
UInt* uint_construct (GType object_type, guint u);
guint uint_hash_static (UInt* that);
gboolean uint_equals_static (UInt* left, UInt* right);
static void uint_finalize (GObject* obj);
GType small_set_tests_get_type (void) G_GNUC_CONST;
enum  {
	SMALL_SET_TESTS_DUMMY_PROPERTY
};
SmallSetTests* small_set_tests_new (void);
SmallSetTests* small_set_tests_construct (GType object_type);
static void __lambda2_ (SmallSetTests* self);
void small_set_tests_test_objects (SmallSetTests* self, gboolean use_hash);
static void ___lambda2__folks_test_case_test_method (gpointer self);
static void __lambda7_ (SmallSetTests* self);
static void ___lambda7__folks_test_case_test_method (gpointer self);
static void __lambda8_ (SmallSetTests* self);
void small_set_tests_test_iter (SmallSetTests* self, gboolean use_hash);
static void ___lambda8__folks_test_case_test_method (gpointer self);
static void __lambda13_ (SmallSetTests* self);
static void ___lambda13__folks_test_case_test_method (gpointer self);
static void __lambda14_ (SmallSetTests* self);
void small_set_tests_test_readonly (SmallSetTests* self, gboolean use_hash);
static void ___lambda14__folks_test_case_test_method (gpointer self);
static void __lambda17_ (SmallSetTests* self);
static void ___lambda17__folks_test_case_test_method (gpointer self);
static void __lambda18_ (SmallSetTests* self);
void small_set_tests_test_direct (SmallSetTests* self, gboolean use_hash);
static void ___lambda18__folks_test_case_test_method (gpointer self);
static void __lambda19_ (SmallSetTests* self);
static void ___lambda19__folks_test_case_test_method (gpointer self);
static void __lambda20_ (SmallSetTests* self);
void small_set_tests_test_strings (SmallSetTests* self, gboolean use_hash);
static void ___lambda20__folks_test_case_test_method (gpointer self);
static void __lambda21_ (SmallSetTests* self);
static void ___lambda21__folks_test_case_test_method (gpointer self);
void small_set_tests_test_cheating (SmallSetTests* self);
static void _small_set_tests_test_cheating_folks_test_case_test_method (gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static guint _uint_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _uint_equals_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gboolean __lambda3_ (Block1Data* _data1_, UInt* obj);
static gboolean ___lambda3__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda4_ (Block1Data* _data1_, UInt* obj);
static gboolean ___lambda4__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda5_ (Block1Data* _data1_, UInt* obj);
static gboolean ___lambda5__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda6_ (Block1Data* _data1_, UInt* obj);
static gboolean ___lambda6__gee_forall_func (gpointer g, gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static gboolean __lambda9_ (Block2Data* _data2_, UInt* obj);
static gboolean ___lambda9__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda10_ (Block2Data* _data2_, UInt* obj);
static gboolean ___lambda10__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda11_ (Block2Data* _data2_, UInt* obj);
static gboolean ___lambda11__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda12_ (Block2Data* _data2_, UInt* obj);
static gboolean ___lambda12__gee_forall_func (gpointer g, gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static gboolean __lambda15_ (Block3Data* _data3_, UInt* obj);
static gboolean ___lambda15__gee_forall_func (gpointer g, gpointer self);
static gboolean __lambda16_ (Block3Data* _data3_, UInt* obj);
static gboolean ___lambda16__gee_forall_func (gpointer g, gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static gboolean __lambda22_ (Block4Data* _data4_, UInt* obj);
static gboolean ___lambda22__gee_forall_func (gpointer g, gpointer self);
gint _vala_main (gchar** args, int args_length1);


DirectEq* direct_eq_construct (GType object_type, guint u) {
	DirectEq * self = NULL;
	guint _tmp0_ = 0U;
#line 29 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = (DirectEq*) g_object_new (object_type, NULL);
#line 31 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = u;
#line 31 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self->u = _tmp0_;
#line 29 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return self;
#line 229 "small-set.c"
}


DirectEq* direct_eq_new (guint u) {
#line 29 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return direct_eq_construct (TYPE_DIRECT_EQ, u);
#line 236 "small-set.c"
}


static void direct_eq_class_init (DirectEqClass * klass) {
#line 25 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	direct_eq_parent_class = g_type_class_peek_parent (klass);
#line 25 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	G_OBJECT_CLASS (klass)->finalize = direct_eq_finalize;
#line 245 "small-set.c"
}


static void direct_eq_instance_init (DirectEq * self) {
}


static void direct_eq_finalize (GObject* obj) {
	DirectEq * self;
#line 25 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_DIRECT_EQ, DirectEq);
#line 25 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	G_OBJECT_CLASS (direct_eq_parent_class)->finalize (obj);
#line 259 "small-set.c"
}


GType direct_eq_get_type (void) {
	static volatile gsize direct_eq_type_id__volatile = 0;
	if (g_once_init_enter (&direct_eq_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DirectEqClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) direct_eq_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DirectEq), 0, (GInstanceInitFunc) direct_eq_instance_init, NULL };
		GType direct_eq_type_id;
		direct_eq_type_id = g_type_register_static (G_TYPE_OBJECT, "DirectEq", &g_define_type_info, 0);
		g_once_init_leave (&direct_eq_type_id__volatile, direct_eq_type_id);
	}
	return direct_eq_type_id__volatile;
}


UInt* uint_construct (GType object_type, guint u) {
	UInt * self = NULL;
	guint _tmp0_ = 0U;
#line 40 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = (UInt*) g_object_new (object_type, NULL);
#line 42 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = u;
#line 42 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self->u = _tmp0_;
#line 40 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return self;
#line 286 "small-set.c"
}


UInt* uint_new (guint u) {
#line 40 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return uint_construct (TYPE_UINT, u);
#line 293 "small-set.c"
}


guint uint_hash_static (UInt* that) {
	guint result = 0U;
	UInt* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 45 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (that != NULL, 0U);
#line 47 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = that;
#line 47 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = _tmp0_->u;
#line 47 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = _tmp1_;
#line 47 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 311 "small-set.c"
}


gboolean uint_equals_static (UInt* left, UInt* right) {
	gboolean result = FALSE;
	UInt* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	UInt* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 50 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (left != NULL, FALSE);
#line 50 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (right != NULL, FALSE);
#line 52 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = left;
#line 52 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = _tmp0_->u;
#line 52 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = right;
#line 52 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp3_ = _tmp2_->u;
#line 52 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = _tmp1_ == _tmp3_;
#line 52 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 337 "small-set.c"
}


static void uint_class_init (UIntClass * klass) {
#line 36 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	uint_parent_class = g_type_class_peek_parent (klass);
#line 36 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	G_OBJECT_CLASS (klass)->finalize = uint_finalize;
#line 346 "small-set.c"
}


static void uint_instance_init (UInt * self) {
}


static void uint_finalize (GObject* obj) {
	UInt * self;
#line 36 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_UINT, UInt);
#line 36 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	G_OBJECT_CLASS (uint_parent_class)->finalize (obj);
#line 360 "small-set.c"
}


GType uint_get_type (void) {
	static volatile gsize uint_type_id__volatile = 0;
	if (g_once_init_enter (&uint_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (UIntClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) uint_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (UInt), 0, (GInstanceInitFunc) uint_instance_init, NULL };
		GType uint_type_id;
		uint_type_id = g_type_register_static (G_TYPE_OBJECT, "UInt", &g_define_type_info, 0);
		g_once_init_leave (&uint_type_id__volatile, uint_type_id);
	}
	return uint_type_id__volatile;
}


static void __lambda2_ (SmallSetTests* self) {
#line 61 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_objects (self, TRUE);
#line 379 "small-set.c"
}


static void ___lambda2__folks_test_case_test_method (gpointer self) {
#line 61 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda2_ (self);
#line 386 "small-set.c"
}


static void __lambda7_ (SmallSetTests* self) {
#line 62 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_objects (self, FALSE);
#line 393 "small-set.c"
}


static void ___lambda7__folks_test_case_test_method (gpointer self) {
#line 62 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda7_ (self);
#line 400 "small-set.c"
}


static void __lambda8_ (SmallSetTests* self) {
#line 63 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_iter (self, TRUE);
#line 407 "small-set.c"
}


static void ___lambda8__folks_test_case_test_method (gpointer self) {
#line 63 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda8_ (self);
#line 414 "small-set.c"
}


static void __lambda13_ (SmallSetTests* self) {
#line 64 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_iter (self, FALSE);
#line 421 "small-set.c"
}


static void ___lambda13__folks_test_case_test_method (gpointer self) {
#line 64 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda13_ (self);
#line 428 "small-set.c"
}


static void __lambda14_ (SmallSetTests* self) {
#line 65 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_readonly (self, TRUE);
#line 435 "small-set.c"
}


static void ___lambda14__folks_test_case_test_method (gpointer self) {
#line 65 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda14_ (self);
#line 442 "small-set.c"
}


static void __lambda17_ (SmallSetTests* self) {
#line 66 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_readonly (self, FALSE);
#line 449 "small-set.c"
}


static void ___lambda17__folks_test_case_test_method (gpointer self) {
#line 66 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda17_ (self);
#line 456 "small-set.c"
}


static void __lambda18_ (SmallSetTests* self) {
#line 67 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_direct (self, TRUE);
#line 463 "small-set.c"
}


static void ___lambda18__folks_test_case_test_method (gpointer self) {
#line 67 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda18_ (self);
#line 470 "small-set.c"
}


static void __lambda19_ (SmallSetTests* self) {
#line 68 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_direct (self, FALSE);
#line 477 "small-set.c"
}


static void ___lambda19__folks_test_case_test_method (gpointer self) {
#line 68 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda19_ (self);
#line 484 "small-set.c"
}


static void __lambda20_ (SmallSetTests* self) {
#line 69 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_strings (self, TRUE);
#line 491 "small-set.c"
}


static void ___lambda20__folks_test_case_test_method (gpointer self) {
#line 69 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda20_ (self);
#line 498 "small-set.c"
}


static void __lambda21_ (SmallSetTests* self) {
#line 70 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_strings (self, FALSE);
#line 505 "small-set.c"
}


static void ___lambda21__folks_test_case_test_method (gpointer self) {
#line 70 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	__lambda21_ (self);
#line 512 "small-set.c"
}


static void _small_set_tests_test_cheating_folks_test_case_test_method (gpointer self) {
#line 71 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_test_cheating (self);
#line 519 "small-set.c"
}


SmallSetTests* small_set_tests_construct (GType object_type) {
	SmallSetTests * self = NULL;
#line 60 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = (SmallSetTests*) folks_test_case_construct (object_type, "SmallSet");
#line 61 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "objects_hash", ___lambda2__folks_test_case_test_method, self);
#line 62 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "objects", ___lambda7__folks_test_case_test_method, self);
#line 63 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "iter_hash", ___lambda8__folks_test_case_test_method, self);
#line 64 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "iter", ___lambda13__folks_test_case_test_method, self);
#line 65 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "readonly_hash", ___lambda14__folks_test_case_test_method, self);
#line 66 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "readonly", ___lambda17__folks_test_case_test_method, self);
#line 67 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "direct_hash", ___lambda18__folks_test_case_test_method, self);
#line 68 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "direct", ___lambda19__folks_test_case_test_method, self);
#line 69 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "string_hash", ___lambda20__folks_test_case_test_method, self);
#line 70 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "string", ___lambda21__folks_test_case_test_method, self);
#line 71 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "cheating", _small_set_tests_test_cheating_folks_test_case_test_method, self);
#line 58 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return self;
#line 551 "small-set.c"
}


SmallSetTests* small_set_tests_new (void) {
#line 58 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return small_set_tests_construct (TYPE_SMALL_SET_TESTS);
#line 558 "small-set.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return _data1_;
#line 567 "small-set.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 576 "small-set.c"
		SmallSetTests * self;
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		self = _data1_->self;
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_data1_->ten);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (self);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		g_slice_free (Block1Data, _data1_);
#line 586 "small-set.c"
	}
}


static guint _uint_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = uint_hash_static (v);
#line 76 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 596 "small-set.c"
}


static gboolean _uint_equals_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = uint_equals_static (a, b);
#line 76 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 605 "small-set.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return self ? g_object_ref (self) : NULL;
#line 612 "small-set.c"
}


static gboolean __lambda3_ (Block1Data* _data1_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 98 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data1_->self;
#line 98 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 100 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data1_->sum;
#line 100 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 100 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 100 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->sum = _tmp0_ + _tmp2_;
#line 101 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 101 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 101 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 640 "small-set.c"
}


static gboolean ___lambda3__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda3_ (self, g);
#line 98 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 649 "small-set.c"
}


static gboolean __lambda4_ (Block1Data* _data1_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 112 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data1_->self;
#line 112 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 114 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data1_->sum;
#line 114 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 114 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 114 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->sum = _tmp0_ + _tmp2_;
#line 115 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = FALSE;
#line 115 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 115 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 677 "small-set.c"
}


static gboolean ___lambda4__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda4_ (self, g);
#line 112 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 686 "small-set.c"
}


static gboolean __lambda5_ (Block1Data* _data1_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	UInt* _tmp0_ = NULL;
	UInt* _tmp1_ = NULL;
#line 123 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data1_->self;
#line 123 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 126 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data1_->ten;
#line 126 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 126 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp0_ != _tmp1_, "ten != obj");
#line 127 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 127 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 127 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 711 "small-set.c"
}


static gboolean ___lambda5__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda5_ (self, g);
#line 123 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 720 "small-set.c"
}


static gboolean __lambda6_ (Block1Data* _data1_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	UInt* _tmp0_ = NULL;
	UInt* _tmp1_ = NULL;
#line 138 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data1_->self;
#line 138 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 140 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data1_->ten;
#line 140 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 140 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp0_ != _tmp1_, "ten != obj");
#line 141 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 141 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 141 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 745 "small-set.c"
}


static gboolean ___lambda6__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda6_ (self, g);
#line 138 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 754 "small-set.c"
}


void small_set_tests_test_objects (SmallSetTests* self, gboolean use_hash) {
	Block1Data* _data1_;
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeSet* objects = NULL;
	GeeSet* _tmp6_ = NULL;
	GeeSet* _tmp7_ = NULL;
	GeeSet* _tmp8_ = NULL;
	GeeSet* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp11_ = FALSE;
	GeeSet* _tmp12_ = NULL;
	gint _tmp13_ = 0;
	gint _tmp14_ = 0;
	GeeSet* _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	GeeSet* _tmp18_ = NULL;
	UInt* _tmp19_ = NULL;
	UInt* _tmp20_ = NULL;
	GeeSet* _tmp21_ = NULL;
	UInt* _tmp22_ = NULL;
	UInt* _tmp23_ = NULL;
	GeeSet* _tmp24_ = NULL;
	UInt* _tmp25_ = NULL;
	UInt* _tmp26_ = NULL;
	GeeSet* _tmp27_ = NULL;
	UInt* _tmp28_ = NULL;
	UInt* _tmp29_ = NULL;
	GeeSet* _tmp30_ = NULL;
	UInt* _tmp31_ = NULL;
	UInt* _tmp32_ = NULL;
	GeeSet* _tmp33_ = NULL;
	GeeSet* _tmp34_ = NULL;
	gboolean _tmp35_ = FALSE;
	gboolean _tmp36_ = FALSE;
	GeeSet* _tmp37_ = NULL;
	gboolean _tmp38_ = FALSE;
	gboolean _tmp39_ = FALSE;
	GeeSet* _tmp40_ = NULL;
	gint _tmp41_ = 0;
	gint _tmp42_ = 0;
	gboolean res = FALSE;
	GeeSet* _tmp43_ = NULL;
	gboolean _tmp44_ = FALSE;
	gboolean _tmp45_ = FALSE;
	guint _tmp47_ = 0U;
	GeeSet* _tmp48_ = NULL;
	gboolean _tmp49_ = FALSE;
	gboolean _tmp50_ = FALSE;
	gboolean _tmp51_ = FALSE;
	gboolean _tmp52_ = FALSE;
	gboolean _tmp53_ = FALSE;
	gboolean _tmp54_ = FALSE;
	guint _tmp55_ = 0U;
	gboolean _tmp57_ = FALSE;
	gboolean _tmp59_ = FALSE;
	gboolean _tmp61_ = FALSE;
	gboolean _tmp63_ = FALSE;
	UInt* _tmp64_ = NULL;
	GeeSet* _tmp65_ = NULL;
	GeeSet* _tmp66_ = NULL;
	UInt* _tmp67_ = NULL;
	gboolean _tmp68_ = FALSE;
	GeeSet* _tmp69_ = NULL;
	UInt* _tmp70_ = NULL;
	gboolean _tmp71_ = FALSE;
	GeeSet* _tmp72_ = NULL;
	UInt* _tmp73_ = NULL;
	gboolean _tmp74_ = FALSE;
	gboolean _tmp75_ = FALSE;
	GeeSet* _tmp76_ = NULL;
	gint _tmp77_ = 0;
	gint _tmp78_ = 0;
	GeeSet* _tmp79_ = NULL;
	GeeSet* _tmp80_ = NULL;
	UInt* _tmp81_ = NULL;
	guint _tmp91_ = 0U;
	GeeSet* _tmp92_ = NULL;
	UInt* _tmp93_ = NULL;
	gboolean _tmp94_ = FALSE;
	gboolean _tmp95_ = FALSE;
	guint _tmp105_ = 0U;
	GeeSet* _tmp106_ = NULL;
	GeeSet* _tmp107_ = NULL;
	gint _tmp108_ = 0;
	gint _tmp109_ = 0;
	GeeSet* _tmp110_ = NULL;
	gboolean _tmp111_ = FALSE;
	gboolean _tmp112_ = FALSE;
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->_ref_count_ = 1;
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->self = g_object_ref (self);
#line 76 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 76 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 77 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = gee_hash_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 77 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	hash = _tmp1_;
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp3_ = use_hash;
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp3_) {
#line 872 "small-set.c"
		GeeHashSet* _tmp4_ = NULL;
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp4_ = hash;
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GEE_TYPE_SET) ? ((GeeSet*) _tmp4_) : NULL;
#line 878 "small-set.c"
	} else {
		FolksSmallSet* _tmp5_ = NULL;
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp5_ = small;
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GEE_TYPE_SET) ? ((GeeSet*) _tmp5_) : NULL;
#line 885 "small-set.c"
	}
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp6_ = _tmp2_;
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 79 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	objects = _tmp7_;
#line 81 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp8_ = objects;
#line 81 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp8_ != NULL, "objects != null");
#line 82 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp9_ = objects;
#line 82 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp10_ = gee_collection_get_read_only ((GeeCollection*) _tmp9_);
#line 82 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp11_ = _tmp10_;
#line 82 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp11_, "!objects.read_only");
#line 83 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp12_ = objects;
#line 83 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp13_ = gee_collection_get_size ((GeeCollection*) _tmp12_);
#line 83 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp14_ = _tmp13_;
#line 83 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp14_ == 0, "objects.size == 0");
#line 84 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp15_ = objects;
#line 84 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp16_ = gee_collection_get_is_empty ((GeeCollection*) _tmp15_);
#line 84 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp17_ = _tmp16_;
#line 84 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp17_, "objects.is_empty");
#line 86 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp18_ = objects;
#line 86 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp19_ = uint_new ((guint) 10000);
#line 86 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp20_ = _tmp19_;
#line 86 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp18_, _tmp20_);
#line 86 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp20_);
#line 87 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp21_ = objects;
#line 87 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp22_ = uint_new ((guint) 1);
#line 87 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp23_ = _tmp22_;
#line 87 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp21_, _tmp23_);
#line 87 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp23_);
#line 88 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp24_ = objects;
#line 88 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp25_ = uint_new ((guint) 10);
#line 88 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp26_ = _tmp25_;
#line 88 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp24_, _tmp26_);
#line 88 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp26_);
#line 89 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp27_ = objects;
#line 89 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp28_ = uint_new ((guint) 100);
#line 89 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp29_ = _tmp28_;
#line 89 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp27_, _tmp29_);
#line 89 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp29_);
#line 90 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp30_ = objects;
#line 90 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp31_ = uint_new ((guint) 1000);
#line 90 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp32_ = _tmp31_;
#line 90 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp30_, _tmp32_);
#line 90 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp32_);
#line 92 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp33_ = objects;
#line 92 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp33_ != NULL, "objects != null");
#line 93 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp34_ = objects;
#line 93 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp35_ = gee_collection_get_read_only ((GeeCollection*) _tmp34_);
#line 93 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp36_ = _tmp35_;
#line 93 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp36_, "!objects.read_only");
#line 94 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp37_ = objects;
#line 94 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp38_ = gee_collection_get_is_empty ((GeeCollection*) _tmp37_);
#line 94 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp39_ = _tmp38_;
#line 94 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp39_, "!objects.is_empty");
#line 95 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp40_ = objects;
#line 95 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp41_ = gee_collection_get_size ((GeeCollection*) _tmp40_);
#line 95 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp42_ = _tmp41_;
#line 95 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp42_ == 5, "objects.size == 5");
#line 97 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->sum = (guint) 0;
#line 98 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp43_ = objects;
#line 98 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp44_ = gee_traversable_foreach ((GeeTraversable*) _tmp43_, ___lambda3__gee_forall_func, _data1_);
#line 98 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	res = _tmp44_;
#line 106 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp45_ = use_hash;
#line 106 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (!_tmp45_) {
#line 1011 "small-set.c"
		gboolean _tmp46_ = FALSE;
#line 107 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp46_ = res;
#line 107 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_vala_assert (_tmp46_ == TRUE, "res == true");
#line 1017 "small-set.c"
	}
#line 109 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp47_ = _data1_->sum;
#line 109 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp47_ == ((guint) 11111), "sum == 11111");
#line 111 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->sum = (guint) 0;
#line 112 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp48_ = objects;
#line 112 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp49_ = gee_traversable_foreach ((GeeTraversable*) _tmp48_, ___lambda4__gee_forall_func, _data1_);
#line 112 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	res = _tmp49_;
#line 117 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp50_ = res;
#line 117 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp50_ == FALSE, "res == false");
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp55_ = _data1_->sum;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp55_ == ((guint) 1)) {
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp54_ = TRUE;
#line 1041 "small-set.c"
	} else {
		guint _tmp56_ = 0U;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp56_ = _data1_->sum;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp54_ = _tmp56_ == ((guint) 10);
#line 1048 "small-set.c"
	}
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp57_ = _tmp54_;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp57_) {
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp53_ = TRUE;
#line 1056 "small-set.c"
	} else {
		guint _tmp58_ = 0U;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp58_ = _data1_->sum;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp53_ = _tmp58_ == ((guint) 100);
#line 1063 "small-set.c"
	}
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp59_ = _tmp53_;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp59_) {
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp52_ = TRUE;
#line 1071 "small-set.c"
	} else {
		guint _tmp60_ = 0U;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp60_ = _data1_->sum;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp52_ = _tmp60_ == ((guint) 1000);
#line 1078 "small-set.c"
	}
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp61_ = _tmp52_;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp61_) {
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp51_ = TRUE;
#line 1086 "small-set.c"
	} else {
		guint _tmp62_ = 0U;
#line 119 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp62_ = _data1_->sum;
#line 119 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp51_ = _tmp62_ == ((guint) 10000);
#line 1093 "small-set.c"
	}
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp63_ = _tmp51_;
#line 118 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp63_, "sum == 1 || sum == 10 || sum == 100 || sum == 1000 ||         sum == 10000");
#line 121 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp64_ = uint_new ((guint) 10);
#line 121 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->ten = _tmp64_;
#line 123 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp65_ = objects;
#line 123 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp65_, ___lambda5__gee_forall_func, _data1_);
#line 131 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp66_ = objects;
#line 131 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp67_ = _data1_->ten;
#line 131 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp68_ = gee_collection_contains ((GeeCollection*) _tmp66_, _tmp67_);
#line 131 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp68_, "objects.contains (ten)");
#line 133 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp69_ = objects;
#line 133 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp70_ = _data1_->ten;
#line 133 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp71_ = gee_collection_contains ((GeeCollection*) _tmp69_, _tmp70_);
#line 133 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp71_, "ten in objects");
#line 135 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp72_ = objects;
#line 135 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp73_ = _data1_->ten;
#line 135 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp74_ = gee_collection_add ((GeeCollection*) _tmp72_, _tmp73_);
#line 135 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	res = _tmp74_;
#line 136 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp75_ = res;
#line 136 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp75_ == FALSE, "res == false");
#line 137 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp76_ = objects;
#line 137 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp77_ = gee_collection_get_size ((GeeCollection*) _tmp76_);
#line 137 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp78_ = _tmp77_;
#line 137 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp78_ == 5, "objects.size == 5");
#line 138 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp79_ = objects;
#line 138 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp79_, ___lambda6__gee_forall_func, _data1_);
#line 144 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp80_ = objects;
#line 144 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp81_ = _data1_->ten;
#line 144 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_remove ((GeeCollection*) _tmp80_, _tmp81_);
#line 147 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->sum = (guint) 0;
#line 1155 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp82_ = NULL;
		GeeIterator* _tmp83_ = NULL;
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp82_ = objects;
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp83_ = gee_iterable_iterator ((GeeIterable*) _tmp82_);
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_it = _tmp83_;
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 1168 "small-set.c"
			GeeIterator* _tmp84_ = NULL;
			gboolean _tmp85_ = FALSE;
			UInt* obj = NULL;
			GeeIterator* _tmp86_ = NULL;
			gpointer _tmp87_ = NULL;
			guint _tmp88_ = 0U;
			UInt* _tmp89_ = NULL;
			guint _tmp90_ = 0U;
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp84_ = _obj_it;
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp85_ = gee_iterator_next (_tmp84_);
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			if (!_tmp85_) {
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
				break;
#line 1185 "small-set.c"
			}
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp86_ = _obj_it;
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp87_ = gee_iterator_get (_tmp86_);
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp87_;
#line 149 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp88_ = _data1_->sum;
#line 149 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp89_ = obj;
#line 149 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp90_ = _tmp89_->u;
#line 149 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_data1_->sum = _tmp88_ + _tmp90_;
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 1203 "small-set.c"
		}
#line 148 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 1207 "small-set.c"
	}
#line 150 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp91_ = _data1_->sum;
#line 150 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp91_ == ((guint) 11101), "sum == 11101");
#line 153 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp92_ = objects;
#line 153 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp93_ = _data1_->ten;
#line 153 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp94_ = gee_collection_add ((GeeCollection*) _tmp92_, _tmp93_);
#line 153 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	res = _tmp94_;
#line 154 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp95_ = res;
#line 154 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp95_ == TRUE, "res == true");
#line 156 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_->sum = (guint) 0;
#line 1227 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp96_ = NULL;
		GeeIterator* _tmp97_ = NULL;
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp96_ = objects;
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp97_ = gee_iterable_iterator ((GeeIterable*) _tmp96_);
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_it = _tmp97_;
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 1240 "small-set.c"
			GeeIterator* _tmp98_ = NULL;
			gboolean _tmp99_ = FALSE;
			UInt* obj = NULL;
			GeeIterator* _tmp100_ = NULL;
			gpointer _tmp101_ = NULL;
			guint _tmp102_ = 0U;
			UInt* _tmp103_ = NULL;
			guint _tmp104_ = 0U;
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp98_ = _obj_it;
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp99_ = gee_iterator_next (_tmp98_);
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			if (!_tmp99_) {
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
				break;
#line 1257 "small-set.c"
			}
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp100_ = _obj_it;
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp101_ = gee_iterator_get (_tmp100_);
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp101_;
#line 158 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp102_ = _data1_->sum;
#line 158 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp103_ = obj;
#line 158 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp104_ = _tmp103_->u;
#line 158 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_data1_->sum = _tmp102_ + _tmp104_;
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 1275 "small-set.c"
		}
#line 157 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 1279 "small-set.c"
	}
#line 159 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp105_ = _data1_->sum;
#line 159 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp105_ == ((guint) 11111), "sum == 11111");
#line 161 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp106_ = objects;
#line 161 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_clear ((GeeCollection*) _tmp106_);
#line 162 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp107_ = objects;
#line 162 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp108_ = gee_collection_get_size ((GeeCollection*) _tmp107_);
#line 162 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp109_ = _tmp108_;
#line 162 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp109_ == 0, "objects.size == 0");
#line 163 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp110_ = objects;
#line 163 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp111_ = gee_collection_get_is_empty ((GeeCollection*) _tmp110_);
#line 163 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp112_ = _tmp111_;
#line 163 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp112_, "objects.is_empty");
#line 1305 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp113_ = NULL;
		GeeIterator* _tmp114_ = NULL;
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp113_ = objects;
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp114_ = gee_iterable_iterator ((GeeIterable*) _tmp113_);
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_it = _tmp114_;
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 1318 "small-set.c"
			gboolean _tmp115_ = FALSE;
			UInt* obj = NULL;
			gpointer _tmp116_ = NULL;
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp115_ = gee_iterator_next (_obj_it);
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			if (!_tmp115_) {
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
				break;
#line 1328 "small-set.c"
			}
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp116_ = gee_iterator_get (_obj_it);
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp116_;
#line 165 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			g_assert_not_reached ();
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 1338 "small-set.c"
		}
#line 164 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 1342 "small-set.c"
	}
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (objects);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	block1_data_unref (_data1_);
#line 74 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data1_ = NULL;
#line 1354 "small-set.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return _data2_;
#line 1363 "small-set.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1372 "small-set.c"
		SmallSetTests * self;
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		self = _data2_->self;
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (self);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		g_slice_free (Block2Data, _data2_);
#line 1380 "small-set.c"
	}
}


static gboolean __lambda9_ (Block2Data* _data2_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 219 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data2_->self;
#line 219 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 221 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data2_->sum;
#line 221 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 221 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 221 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp0_ + _tmp2_;
#line 222 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 222 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 222 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 1409 "small-set.c"
}


static gboolean ___lambda9__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda9_ (self, g);
#line 219 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 1418 "small-set.c"
}


static gboolean __lambda10_ (Block2Data* _data2_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 228 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data2_->self;
#line 228 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 230 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data2_->sum;
#line 230 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 230 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 230 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp0_ + _tmp2_;
#line 231 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = FALSE;
#line 231 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 231 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 1446 "small-set.c"
}


static gboolean ___lambda10__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda10_ (self, g);
#line 228 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 1455 "small-set.c"
}


static gboolean __lambda11_ (Block2Data* _data2_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 247 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data2_->self;
#line 247 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 249 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data2_->sum;
#line 249 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 249 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 249 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp0_ + _tmp2_;
#line 250 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 250 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 250 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 1483 "small-set.c"
}


static gboolean ___lambda11__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda11_ (self, g);
#line 247 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 1492 "small-set.c"
}


static gboolean __lambda12_ (Block2Data* _data2_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
#line 261 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data2_->self;
#line 261 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 264 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data2_->sum;
#line 264 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp0_ + 1;
#line 265 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 265 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 265 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 1514 "small-set.c"
}


static gboolean ___lambda12__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda12_ (self, g);
#line 261 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 1523 "small-set.c"
}


void small_set_tests_test_iter (SmallSetTests* self, gboolean use_hash) {
	Block2Data* _data2_;
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeSet* objects = NULL;
	GeeSet* _tmp6_ = NULL;
	GeeSet* _tmp7_ = NULL;
	GeeIterator* iter = NULL;
	GeeSet* _tmp8_ = NULL;
	GeeIterator* _tmp9_ = NULL;
	GeeIterator* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	gboolean _tmp12_ = FALSE;
	GeeIterator* _tmp13_ = NULL;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	GeeIterator* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	gboolean res = FALSE;
	GeeIterator* _tmp18_ = NULL;
	gboolean _tmp19_ = FALSE;
	gboolean _tmp20_ = FALSE;
	GeeIterator* _tmp21_ = NULL;
	gboolean _tmp22_ = FALSE;
	gboolean _tmp23_ = FALSE;
	GeeIterator* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
	GeeSet* _tmp26_ = NULL;
	UInt* _tmp27_ = NULL;
	UInt* _tmp28_ = NULL;
	GeeSet* _tmp29_ = NULL;
	UInt* _tmp30_ = NULL;
	UInt* _tmp31_ = NULL;
	GeeSet* _tmp32_ = NULL;
	UInt* _tmp33_ = NULL;
	UInt* _tmp34_ = NULL;
	GeeSet* _tmp35_ = NULL;
	UInt* _tmp36_ = NULL;
	UInt* _tmp37_ = NULL;
	GeeSet* _tmp38_ = NULL;
	UInt* _tmp39_ = NULL;
	UInt* _tmp40_ = NULL;
	GeeSet* _tmp41_ = NULL;
	gint _tmp42_ = 0;
	gint _tmp43_ = 0;
	GeeSet* _tmp44_ = NULL;
	GeeIterator* _tmp45_ = NULL;
	GeeIterator* _tmp46_ = NULL;
	gboolean _tmp47_ = FALSE;
	gboolean _tmp48_ = FALSE;
	GeeIterator* _tmp49_ = NULL;
	gboolean _tmp50_ = FALSE;
	gboolean _tmp51_ = FALSE;
	GeeIterator* _tmp52_ = NULL;
	gboolean _tmp53_ = FALSE;
	GeeIterator* _tmp54_ = NULL;
	gboolean _tmp55_ = FALSE;
	gboolean _tmp56_ = FALSE;
	GeeIterator* _tmp57_ = NULL;
	gboolean _tmp58_ = FALSE;
	gboolean _tmp59_ = FALSE;
	GeeIterator* _tmp60_ = NULL;
	gboolean _tmp61_ = FALSE;
	GeeIterator* _tmp62_ = NULL;
	GeeIterator* _tmp63_ = NULL;
	GeeIterator* _tmp64_ = NULL;
	GeeIterator* _tmp65_ = NULL;
	gboolean _tmp66_ = FALSE;
	gboolean _tmp67_ = FALSE;
	GeeIterator* _tmp68_ = NULL;
	gboolean _tmp69_ = FALSE;
	GeeIterator* _tmp70_ = NULL;
	GeeIterator* _tmp71_ = NULL;
	gboolean _tmp72_ = FALSE;
	gboolean _tmp73_ = FALSE;
	GeeIterator* _tmp74_ = NULL;
	gboolean _tmp75_ = FALSE;
	GeeIterator* _tmp76_ = NULL;
	gboolean _tmp77_ = FALSE;
	gboolean _tmp78_ = FALSE;
	GeeIterator* _tmp79_ = NULL;
	gboolean _tmp80_ = FALSE;
	gboolean _tmp81_ = FALSE;
	GeeIterator* _tmp82_ = NULL;
	gboolean _tmp83_ = FALSE;
	GeeSet* _tmp84_ = NULL;
	GeeIterator* _tmp85_ = NULL;
	GeeIterator* _tmp86_ = NULL;
	guint _tmp87_ = 0U;
	GeeSet* _tmp88_ = NULL;
	GeeIterator* _tmp89_ = NULL;
	GeeIterator* _tmp90_ = NULL;
	gboolean _tmp91_ = FALSE;
	gboolean _tmp92_ = FALSE;
	gboolean _tmp93_ = FALSE;
	gboolean _tmp94_ = FALSE;
	gboolean _tmp95_ = FALSE;
	gboolean _tmp96_ = FALSE;
	guint _tmp97_ = 0U;
	gboolean _tmp99_ = FALSE;
	gboolean _tmp101_ = FALSE;
	gboolean _tmp103_ = FALSE;
	gboolean _tmp105_ = FALSE;
	GeeSet* _tmp106_ = NULL;
	GeeIterator* _tmp107_ = NULL;
	GeeIterator* _tmp108_ = NULL;
	guint _tmp109_ = 0U;
	GeeIterator* _tmp110_ = NULL;
	gpointer _tmp111_ = NULL;
	UInt* _tmp112_ = NULL;
	guint _tmp113_ = 0U;
	GeeIterator* _tmp114_ = NULL;
	guint _tmp115_ = 0U;
	GeeIterator* _tmp116_ = NULL;
	gpointer _tmp117_ = NULL;
	UInt* _tmp118_ = NULL;
	guint _tmp119_ = 0U;
	GeeIterator* _tmp120_ = NULL;
	GeeIterator* _tmp121_ = NULL;
	guint _tmp122_ = 0U;
	GeeSet* _tmp123_ = NULL;
	GeeIterator* _tmp124_ = NULL;
	GeeIterator* _tmp125_ = NULL;
	GeeIterator* _tmp126_ = NULL;
	GeeIterator* _tmp127_ = NULL;
	GeeIterator* _tmp128_ = NULL;
	GeeIterator* _tmp129_ = NULL;
	GeeIterator* _tmp130_ = NULL;
	guint _tmp131_ = 0U;
	GeeSet* _tmp132_ = NULL;
	GeeIterator* _tmp133_ = NULL;
	GeeIterator* _tmp134_ = NULL;
	GeeIterator* _tmp135_ = NULL;
	gboolean _tmp136_ = FALSE;
	gboolean _tmp137_ = FALSE;
	UInt* removed = NULL;
	GeeIterator* _tmp138_ = NULL;
	gpointer _tmp139_ = NULL;
	GeeIterator* _tmp140_ = NULL;
	guint _tmp141_ = 0U;
	UInt* _tmp142_ = NULL;
	guint _tmp143_ = 0U;
	GeeIterator* _tmp144_ = NULL;
	gboolean _tmp145_ = FALSE;
	gboolean _tmp146_ = FALSE;
	guint _tmp154_ = 0U;
	GeeSet* _tmp155_ = NULL;
	UInt* _tmp156_ = NULL;
	GeeSet* _tmp157_ = NULL;
	GeeIterator* _tmp158_ = NULL;
	GeeIterator* _tmp159_ = NULL;
	guint _tmp160_ = 0U;
	GeeIterator* _tmp161_ = NULL;
	gpointer _tmp162_ = NULL;
	UInt* _tmp163_ = NULL;
	guint _tmp164_ = 0U;
	GeeIterator* _tmp165_ = NULL;
	guint _tmp166_ = 0U;
	GeeIterator* _tmp167_ = NULL;
	gpointer _tmp168_ = NULL;
	UInt* _tmp169_ = NULL;
	guint _tmp170_ = 0U;
	GeeIterator* _tmp171_ = NULL;
	GeeIterator* _tmp172_ = NULL;
	gboolean _tmp173_ = FALSE;
	gboolean _tmp174_ = FALSE;
	GeeIterator* _tmp175_ = NULL;
	gpointer _tmp176_ = NULL;
	GeeIterator* _tmp177_ = NULL;
	guint _tmp178_ = 0U;
	UInt* _tmp179_ = NULL;
	guint _tmp180_ = 0U;
	GeeIterator* _tmp181_ = NULL;
	gboolean _tmp182_ = FALSE;
	gboolean _tmp183_ = FALSE;
	guint _tmp191_ = 0U;
	GeeSet* _tmp192_ = NULL;
	UInt* _tmp193_ = NULL;
	GeeSet* _tmp194_ = NULL;
	GeeIterator* _tmp195_ = NULL;
	GeeIterator* _tmp196_ = NULL;
	GeeIterator* _tmp197_ = NULL;
	GeeIterator* _tmp198_ = NULL;
	GeeIterator* _tmp199_ = NULL;
	GeeIterator* _tmp200_ = NULL;
	GeeIterator* _tmp201_ = NULL;
	gboolean _tmp202_ = FALSE;
	gboolean _tmp203_ = FALSE;
	GeeIterator* _tmp204_ = NULL;
	gboolean _tmp205_ = FALSE;
	GeeIterator* _tmp206_ = NULL;
	gpointer _tmp207_ = NULL;
	GeeIterator* _tmp208_ = NULL;
	guint _tmp209_ = 0U;
	UInt* _tmp210_ = NULL;
	guint _tmp211_ = 0U;
	GeeIterator* _tmp212_ = NULL;
	gboolean _tmp213_ = FALSE;
	gboolean _tmp214_ = FALSE;
	GeeIterator* _tmp215_ = NULL;
	gboolean _tmp216_ = FALSE;
	guint _tmp226_ = 0U;
	GeeSet* _tmp227_ = NULL;
	UInt* _tmp228_ = NULL;
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->_ref_count_ = 1;
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->self = g_object_ref (self);
#line 170 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 170 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 171 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = gee_hash_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 171 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	hash = _tmp1_;
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp3_ = use_hash;
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp3_) {
#line 1755 "small-set.c"
		GeeHashSet* _tmp4_ = NULL;
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp4_ = hash;
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GEE_TYPE_SET) ? ((GeeSet*) _tmp4_) : NULL;
#line 1761 "small-set.c"
	} else {
		FolksSmallSet* _tmp5_ = NULL;
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp5_ = small;
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GEE_TYPE_SET) ? ((GeeSet*) _tmp5_) : NULL;
#line 1768 "small-set.c"
	}
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp6_ = _tmp2_;
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 173 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	objects = _tmp7_;
#line 175 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp8_ = objects;
#line 175 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp9_ = gee_iterable_iterator ((GeeIterable*) _tmp8_);
#line 175 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp9_;
#line 176 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp10_ = iter;
#line 176 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp11_ = gee_iterator_get_valid (_tmp10_);
#line 176 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp12_ = _tmp11_;
#line 176 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp12_, "!iter.valid");
#line 177 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp13_ = iter;
#line 177 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp14_ = gee_iterator_get_read_only (_tmp13_);
#line 177 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp15_ = _tmp14_;
#line 177 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp15_, "!iter.read_only");
#line 178 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp16_ = iter;
#line 178 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp17_ = gee_iterator_has_next (_tmp16_);
#line 178 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp17_, "!iter.has_next ()");
#line 179 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp18_ = iter;
#line 179 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp19_ = gee_iterator_next (_tmp18_);
#line 179 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	res = _tmp19_;
#line 180 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp20_ = res;
#line 180 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp20_, "!res");
#line 181 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp21_ = iter;
#line 181 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp22_ = gee_iterator_get_valid (_tmp21_);
#line 181 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp23_ = _tmp22_;
#line 181 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp23_, "!iter.valid");
#line 182 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp24_ = iter;
#line 182 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp25_ = gee_iterator_has_next (_tmp24_);
#line 182 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp25_, "!iter.has_next ()");
#line 184 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp26_ = objects;
#line 184 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp27_ = uint_new ((guint) 1);
#line 184 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp28_ = _tmp27_;
#line 184 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp26_, _tmp28_);
#line 184 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp28_);
#line 185 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp29_ = objects;
#line 185 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp30_ = uint_new ((guint) 10);
#line 185 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp31_ = _tmp30_;
#line 185 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp29_, _tmp31_);
#line 185 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp31_);
#line 186 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp32_ = objects;
#line 186 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp33_ = uint_new ((guint) 100);
#line 186 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp34_ = _tmp33_;
#line 186 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp32_, _tmp34_);
#line 186 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp34_);
#line 187 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp35_ = objects;
#line 187 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp36_ = uint_new ((guint) 1000);
#line 187 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp37_ = _tmp36_;
#line 187 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp35_, _tmp37_);
#line 187 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp37_);
#line 188 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp38_ = objects;
#line 188 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp39_ = uint_new ((guint) 10000);
#line 188 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp40_ = _tmp39_;
#line 188 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp38_, _tmp40_);
#line 188 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp40_);
#line 189 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp41_ = objects;
#line 189 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp42_ = gee_collection_get_size ((GeeCollection*) _tmp41_);
#line 189 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp43_ = _tmp42_;
#line 189 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp43_ == 5, "objects.size == 5");
#line 191 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp44_ = objects;
#line 191 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp45_ = gee_iterable_iterator ((GeeIterable*) _tmp44_);
#line 191 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 191 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp45_;
#line 193 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp46_ = iter;
#line 193 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp47_ = gee_iterator_get_valid (_tmp46_);
#line 193 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp48_ = _tmp47_;
#line 193 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp48_, "!iter.valid");
#line 194 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp49_ = iter;
#line 194 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp50_ = gee_iterator_get_read_only (_tmp49_);
#line 194 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp51_ = _tmp50_;
#line 194 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp51_, "!iter.read_only");
#line 196 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp52_ = iter;
#line 196 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp53_ = gee_iterator_has_next (_tmp52_);
#line 196 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp53_, "iter.has_next ()");
#line 197 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp54_ = iter;
#line 197 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp55_ = gee_iterator_next (_tmp54_);
#line 197 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	res = _tmp55_;
#line 198 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp56_ = res;
#line 198 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp56_, "res");
#line 199 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp57_ = iter;
#line 199 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp58_ = gee_iterator_get_valid (_tmp57_);
#line 199 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp59_ = _tmp58_;
#line 199 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp59_, "iter.valid");
#line 200 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp60_ = iter;
#line 200 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp61_ = gee_iterator_has_next (_tmp60_);
#line 200 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp61_, "iter.has_next ()");
#line 202 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp62_ = iter;
#line 202 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp62_);
#line 203 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp63_ = iter;
#line 203 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp63_);
#line 204 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp64_ = iter;
#line 204 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp64_);
#line 205 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp65_ = iter;
#line 205 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp66_ = gee_iterator_get_valid (_tmp65_);
#line 205 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp67_ = _tmp66_;
#line 205 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp67_, "iter.valid");
#line 206 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp68_ = iter;
#line 206 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp69_ = gee_iterator_has_next (_tmp68_);
#line 206 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp69_, "iter.has_next ()");
#line 207 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp70_ = iter;
#line 207 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp70_);
#line 208 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp71_ = iter;
#line 208 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp72_ = gee_iterator_get_valid (_tmp71_);
#line 208 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp73_ = _tmp72_;
#line 208 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp73_, "iter.valid");
#line 209 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp74_ = iter;
#line 209 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp75_ = gee_iterator_has_next (_tmp74_);
#line 209 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp75_, "!iter.has_next ()");
#line 210 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp76_ = iter;
#line 210 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp77_ = gee_iterator_next (_tmp76_);
#line 210 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	res = _tmp77_;
#line 211 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp78_ = res;
#line 211 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp78_, "!res");
#line 212 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp79_ = iter;
#line 212 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp80_ = gee_iterator_get_valid (_tmp79_);
#line 212 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp81_ = _tmp80_;
#line 212 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp81_, "iter.valid");
#line 213 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp82_ = iter;
#line 213 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp83_ = gee_iterator_has_next (_tmp82_);
#line 213 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp83_, "!iter.has_next ()");
#line 215 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp84_ = objects;
#line 215 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp85_ = gee_iterable_iterator ((GeeIterable*) _tmp84_);
#line 215 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 215 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp85_;
#line 216 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 219 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp86_ = iter;
#line 219 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp86_, ___lambda9__gee_forall_func, _data2_);
#line 224 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp87_ = _data2_->sum;
#line 224 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp87_ == ((guint) 11111), "sum == 11111");
#line 226 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 227 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp88_ = objects;
#line 227 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp89_ = gee_iterable_iterator ((GeeIterable*) _tmp88_);
#line 227 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 227 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp89_;
#line 228 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp90_ = iter;
#line 228 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp91_ = gee_traversable_foreach ((GeeTraversable*) _tmp90_, ___lambda10__gee_forall_func, _data2_);
#line 228 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	res = _tmp91_;
#line 233 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp92_ = res;
#line 233 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp92_ == FALSE, "res == false");
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp97_ = _data2_->sum;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp97_ == ((guint) 1)) {
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp96_ = TRUE;
#line 2052 "small-set.c"
	} else {
		guint _tmp98_ = 0U;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp98_ = _data2_->sum;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp96_ = _tmp98_ == ((guint) 10);
#line 2059 "small-set.c"
	}
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp99_ = _tmp96_;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp99_) {
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp95_ = TRUE;
#line 2067 "small-set.c"
	} else {
		guint _tmp100_ = 0U;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp100_ = _data2_->sum;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp95_ = _tmp100_ == ((guint) 100);
#line 2074 "small-set.c"
	}
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp101_ = _tmp95_;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp101_) {
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp94_ = TRUE;
#line 2082 "small-set.c"
	} else {
		guint _tmp102_ = 0U;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp102_ = _data2_->sum;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp94_ = _tmp102_ == ((guint) 1000);
#line 2089 "small-set.c"
	}
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp103_ = _tmp94_;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp103_) {
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp93_ = TRUE;
#line 2097 "small-set.c"
	} else {
		guint _tmp104_ = 0U;
#line 235 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp104_ = _data2_->sum;
#line 235 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp93_ = _tmp104_ == ((guint) 10000);
#line 2104 "small-set.c"
	}
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp105_ = _tmp93_;
#line 234 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp105_, "sum == 1 || sum == 10 || sum == 100 || sum == 1000 ||         sum == 10000");
#line 237 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 238 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp106_ = objects;
#line 238 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp107_ = gee_iterable_iterator ((GeeIterable*) _tmp106_);
#line 238 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 238 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp107_;
#line 239 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp108_ = iter;
#line 239 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp108_);
#line 240 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp109_ = _data2_->sum;
#line 240 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp110_ = iter;
#line 240 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp111_ = gee_iterator_get (_tmp110_);
#line 240 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp112_ = (UInt*) _tmp111_;
#line 240 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp113_ = _tmp112_->u;
#line 240 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp109_ + _tmp113_;
#line 240 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp112_);
#line 241 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp114_ = iter;
#line 241 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp114_);
#line 242 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp115_ = _data2_->sum;
#line 242 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp116_ = iter;
#line 242 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp117_ = gee_iterator_get (_tmp116_);
#line 242 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp118_ = (UInt*) _tmp117_;
#line 242 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp119_ = _tmp118_->u;
#line 242 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp115_ + _tmp119_;
#line 242 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp118_);
#line 243 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp120_ = iter;
#line 243 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp120_);
#line 247 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp121_ = iter;
#line 247 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp121_, ___lambda11__gee_forall_func, _data2_);
#line 252 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp122_ = _data2_->sum;
#line 252 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp122_ == ((guint) 11111), "sum == 11111");
#line 254 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 255 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp123_ = objects;
#line 255 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp124_ = gee_iterable_iterator ((GeeIterable*) _tmp123_);
#line 255 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 255 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp124_;
#line 256 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp125_ = iter;
#line 256 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp125_);
#line 257 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp126_ = iter;
#line 257 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp126_);
#line 258 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp127_ = iter;
#line 258 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp127_);
#line 259 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp128_ = iter;
#line 259 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp128_);
#line 260 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp129_ = iter;
#line 260 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp129_);
#line 261 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp130_ = iter;
#line 261 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp130_, ___lambda12__gee_forall_func, _data2_);
#line 267 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp131_ = _data2_->sum;
#line 267 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp131_ == ((guint) 1), "sum == 1");
#line 270 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 271 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp132_ = objects;
#line 271 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp133_ = gee_iterable_iterator ((GeeIterable*) _tmp132_);
#line 271 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 271 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp133_;
#line 272 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp134_ = iter;
#line 272 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp134_);
#line 273 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp135_ = iter;
#line 273 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp136_ = gee_iterator_get_valid (_tmp135_);
#line 273 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp137_ = _tmp136_;
#line 273 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp137_, "iter.valid");
#line 274 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp138_ = iter;
#line 274 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp139_ = gee_iterator_get (_tmp138_);
#line 274 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	removed = (UInt*) _tmp139_;
#line 275 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp140_ = iter;
#line 275 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_remove (_tmp140_);
#line 276 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp141_ = _data2_->sum;
#line 276 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp142_ = removed;
#line 276 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp143_ = _tmp142_->u;
#line 276 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp141_ + _tmp143_;
#line 277 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp144_ = iter;
#line 277 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp145_ = gee_iterator_get_valid (_tmp144_);
#line 277 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp146_ = _tmp145_;
#line 277 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp146_, "!iter.valid");
#line 278 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	while (TRUE) {
#line 2256 "small-set.c"
		GeeIterator* _tmp147_ = NULL;
		gboolean _tmp148_ = FALSE;
		guint _tmp149_ = 0U;
		GeeIterator* _tmp150_ = NULL;
		gpointer _tmp151_ = NULL;
		UInt* _tmp152_ = NULL;
		guint _tmp153_ = 0U;
#line 278 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp147_ = iter;
#line 278 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp148_ = gee_iterator_next (_tmp147_);
#line 278 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		if (!_tmp148_) {
#line 278 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			break;
#line 2272 "small-set.c"
		}
#line 279 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp149_ = _data2_->sum;
#line 279 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp150_ = iter;
#line 279 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp151_ = gee_iterator_get (_tmp150_);
#line 279 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp152_ = (UInt*) _tmp151_;
#line 279 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp153_ = _tmp152_->u;
#line 279 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_data2_->sum = _tmp149_ + _tmp153_;
#line 279 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_tmp152_);
#line 2288 "small-set.c"
	}
#line 280 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp154_ = _data2_->sum;
#line 280 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp154_ == ((guint) 11111), "sum == 11111");
#line 282 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp155_ = objects;
#line 282 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp156_ = removed;
#line 282 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp155_, _tmp156_);
#line 285 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 286 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp157_ = objects;
#line 286 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp158_ = gee_iterable_iterator ((GeeIterable*) _tmp157_);
#line 286 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 286 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp158_;
#line 287 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp159_ = iter;
#line 287 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp159_);
#line 288 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp160_ = _data2_->sum;
#line 288 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp161_ = iter;
#line 288 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp162_ = gee_iterator_get (_tmp161_);
#line 288 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp163_ = (UInt*) _tmp162_;
#line 288 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp164_ = _tmp163_->u;
#line 288 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp160_ + _tmp164_;
#line 288 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp163_);
#line 289 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp165_ = iter;
#line 289 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp165_);
#line 290 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp166_ = _data2_->sum;
#line 290 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp167_ = iter;
#line 290 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp168_ = gee_iterator_get (_tmp167_);
#line 290 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp169_ = (UInt*) _tmp168_;
#line 290 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp170_ = _tmp169_->u;
#line 290 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp166_ + _tmp170_;
#line 290 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp169_);
#line 291 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp171_ = iter;
#line 291 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp171_);
#line 292 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp172_ = iter;
#line 292 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp173_ = gee_iterator_get_valid (_tmp172_);
#line 292 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp174_ = _tmp173_;
#line 292 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp174_, "iter.valid");
#line 293 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp175_ = iter;
#line 293 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp176_ = gee_iterator_get (_tmp175_);
#line 293 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (removed);
#line 293 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	removed = (UInt*) _tmp176_;
#line 294 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp177_ = iter;
#line 294 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_remove (_tmp177_);
#line 295 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp178_ = _data2_->sum;
#line 295 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp179_ = removed;
#line 295 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp180_ = _tmp179_->u;
#line 295 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp178_ + _tmp180_;
#line 296 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp181_ = iter;
#line 296 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp182_ = gee_iterator_get_valid (_tmp181_);
#line 296 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp183_ = _tmp182_;
#line 296 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp183_, "!iter.valid");
#line 297 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	while (TRUE) {
#line 2388 "small-set.c"
		GeeIterator* _tmp184_ = NULL;
		gboolean _tmp185_ = FALSE;
		guint _tmp186_ = 0U;
		GeeIterator* _tmp187_ = NULL;
		gpointer _tmp188_ = NULL;
		UInt* _tmp189_ = NULL;
		guint _tmp190_ = 0U;
#line 297 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp184_ = iter;
#line 297 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp185_ = gee_iterator_next (_tmp184_);
#line 297 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		if (!_tmp185_) {
#line 297 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			break;
#line 2404 "small-set.c"
		}
#line 298 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp186_ = _data2_->sum;
#line 298 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp187_ = iter;
#line 298 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp188_ = gee_iterator_get (_tmp187_);
#line 298 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp189_ = (UInt*) _tmp188_;
#line 298 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp190_ = _tmp189_->u;
#line 298 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_data2_->sum = _tmp186_ + _tmp190_;
#line 298 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_tmp189_);
#line 2420 "small-set.c"
	}
#line 299 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp191_ = _data2_->sum;
#line 299 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp191_ == ((guint) 11111), "sum == 11111");
#line 301 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp192_ = objects;
#line 301 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp193_ = removed;
#line 301 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp192_, _tmp193_);
#line 304 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = (guint) 0;
#line 305 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp194_ = objects;
#line 305 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp195_ = gee_iterable_iterator ((GeeIterable*) _tmp194_);
#line 305 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 305 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp195_;
#line 306 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp196_ = iter;
#line 306 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp196_);
#line 307 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp197_ = iter;
#line 307 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp197_);
#line 308 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp198_ = iter;
#line 308 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp198_);
#line 309 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp199_ = iter;
#line 309 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp199_);
#line 310 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp200_ = iter;
#line 310 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_next (_tmp200_);
#line 311 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp201_ = iter;
#line 311 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp202_ = gee_iterator_get_valid (_tmp201_);
#line 311 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp203_ = _tmp202_;
#line 311 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp203_, "iter.valid");
#line 312 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp204_ = iter;
#line 312 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp205_ = gee_iterator_has_next (_tmp204_);
#line 312 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp205_, "!iter.has_next ()");
#line 313 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp206_ = iter;
#line 313 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp207_ = gee_iterator_get (_tmp206_);
#line 313 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (removed);
#line 313 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	removed = (UInt*) _tmp207_;
#line 314 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp208_ = iter;
#line 314 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_iterator_remove (_tmp208_);
#line 315 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp209_ = _data2_->sum;
#line 315 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp210_ = removed;
#line 315 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp211_ = _tmp210_->u;
#line 315 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_->sum = _tmp209_ + _tmp211_;
#line 316 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp212_ = iter;
#line 316 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp213_ = gee_iterator_get_valid (_tmp212_);
#line 316 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp214_ = _tmp213_;
#line 316 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp214_, "!iter.valid");
#line 317 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp215_ = iter;
#line 317 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp216_ = gee_iterator_has_next (_tmp215_);
#line 317 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (!_tmp216_, "!iter.has_next ()");
#line 2510 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp217_ = NULL;
		GeeIterator* _tmp218_ = NULL;
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp217_ = objects;
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp218_ = gee_iterable_iterator ((GeeIterable*) _tmp217_);
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_it = _tmp218_;
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 2523 "small-set.c"
			GeeIterator* _tmp219_ = NULL;
			gboolean _tmp220_ = FALSE;
			UInt* obj = NULL;
			GeeIterator* _tmp221_ = NULL;
			gpointer _tmp222_ = NULL;
			guint _tmp223_ = 0U;
			UInt* _tmp224_ = NULL;
			guint _tmp225_ = 0U;
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp219_ = _obj_it;
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp220_ = gee_iterator_next (_tmp219_);
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			if (!_tmp220_) {
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
				break;
#line 2540 "small-set.c"
			}
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp221_ = _obj_it;
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp222_ = gee_iterator_get (_tmp221_);
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp222_;
#line 319 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp223_ = _data2_->sum;
#line 319 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp224_ = obj;
#line 319 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp225_ = _tmp224_->u;
#line 319 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_data2_->sum = _tmp223_ + _tmp225_;
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 2558 "small-set.c"
		}
#line 318 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 2562 "small-set.c"
	}
#line 320 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp226_ = _data2_->sum;
#line 320 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp226_ == ((guint) 11111), "sum == 11111");
#line 322 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp227_ = objects;
#line 322 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp228_ = removed;
#line 322 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp227_, _tmp228_);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (removed);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (objects);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	block2_data_unref (_data2_);
#line 168 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data2_ = NULL;
#line 2588 "small-set.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return _data3_;
#line 2597 "small-set.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 2606 "small-set.c"
		SmallSetTests * self;
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		self = _data3_->self;
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (self);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		g_slice_free (Block3Data, _data3_);
#line 2614 "small-set.c"
	}
}


static gboolean __lambda15_ (Block3Data* _data3_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 343 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data3_->self;
#line 343 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 345 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data3_->u;
#line 345 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp0_ == ((guint) 0), "u == 0");
#line 346 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 346 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 346 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data3_->u = _tmp2_;
#line 347 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 347 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 347 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 2645 "small-set.c"
}


static gboolean ___lambda15__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda15_ (self, g);
#line 343 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 2654 "small-set.c"
}


static gboolean __lambda16_ (Block3Data* _data3_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	UInt* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
#line 354 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data3_->self;
#line 354 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 356 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data3_->u;
#line 356 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp0_ == ((guint) 0), "u == 0");
#line 357 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = obj;
#line 357 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = _tmp1_->u;
#line 357 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data3_->u = _tmp2_;
#line 358 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 358 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 358 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 2684 "small-set.c"
}


static gboolean ___lambda16__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda16_ (self, g);
#line 354 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 2693 "small-set.c"
}


void small_set_tests_test_readonly (SmallSetTests* self, gboolean use_hash) {
	Block3Data* _data3_;
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeSet* objects = NULL;
	GeeSet* _tmp6_ = NULL;
	GeeSet* _tmp7_ = NULL;
	GeeSet* ro = NULL;
	GeeSet* _tmp8_ = NULL;
	GeeSet* _tmp9_ = NULL;
	GeeSet* _tmp10_ = NULL;
	GeeSet* _tmp11_ = NULL;
	GeeSet* _tmp12_ = NULL;
	GeeSet* _tmp13_ = NULL;
	GeeSet* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	GeeSet* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
	GeeSet* _tmp20_ = NULL;
	UInt* _tmp21_ = NULL;
	UInt* _tmp22_ = NULL;
	GeeSet* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	gint _tmp25_ = 0;
	GeeSet* _tmp26_ = NULL;
	gint _tmp27_ = 0;
	gint _tmp28_ = 0;
	GeeSet* _tmp29_ = NULL;
	guint _tmp30_ = 0U;
	GeeIterator* iter = NULL;
	GeeSet* _tmp31_ = NULL;
	GeeIterator* _tmp32_ = NULL;
	GeeIterator* _tmp33_ = NULL;
	gboolean _tmp34_ = FALSE;
	gboolean _tmp35_ = FALSE;
	GeeIterator* _tmp36_ = NULL;
	guint _tmp37_ = 0U;
	gboolean _tmp38_ = FALSE;
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data3_->_ref_count_ = 1;
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data3_->self = g_object_ref (self);
#line 327 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 327 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 328 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = gee_hash_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 328 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	hash = _tmp1_;
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp3_ = use_hash;
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp3_) {
#line 2761 "small-set.c"
		GeeHashSet* _tmp4_ = NULL;
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp4_ = hash;
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GEE_TYPE_SET) ? ((GeeSet*) _tmp4_) : NULL;
#line 2767 "small-set.c"
	} else {
		FolksSmallSet* _tmp5_ = NULL;
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp5_ = small;
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GEE_TYPE_SET) ? ((GeeSet*) _tmp5_) : NULL;
#line 2774 "small-set.c"
	}
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp6_ = _tmp2_;
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 330 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	objects = _tmp7_;
#line 332 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp8_ = objects;
#line 332 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp9_ = gee_set_get_read_only_view (_tmp8_);
#line 332 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp10_ = _tmp9_;
#line 332 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	ro = _tmp10_;
#line 333 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp11_ = ro;
#line 333 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp11_ != NULL, "ro != null");
#line 334 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp12_ = ro;
#line 334 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp13_ = objects;
#line 334 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp12_ != _tmp13_, "ro != objects");
#line 335 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp14_ = ro;
#line 335 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp15_ = gee_collection_get_read_only ((GeeCollection*) _tmp14_);
#line 335 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp16_ = _tmp15_;
#line 335 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp16_, "ro.read_only");
#line 336 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp17_ = ro;
#line 336 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 336 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp19_ = _tmp18_;
#line 336 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp19_ == 0, "ro.size == 0");
#line 338 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp20_ = objects;
#line 338 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp21_ = uint_new ((guint) 23);
#line 338 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp22_ = _tmp21_;
#line 338 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp20_, _tmp22_);
#line 338 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp22_);
#line 339 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp23_ = objects;
#line 339 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp24_ = gee_collection_get_size ((GeeCollection*) _tmp23_);
#line 339 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp25_ = _tmp24_;
#line 339 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp25_ == 1, "objects.size == 1");
#line 340 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp26_ = ro;
#line 340 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp27_ = gee_collection_get_size ((GeeCollection*) _tmp26_);
#line 340 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp28_ = _tmp27_;
#line 340 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp28_ == 1, "ro.size == 1");
#line 342 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data3_->u = (guint) 0;
#line 343 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp29_ = ro;
#line 343 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp29_, ___lambda15__gee_forall_func, _data3_);
#line 349 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp30_ = _data3_->u;
#line 349 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp30_ == ((guint) 23), "u == 23");
#line 351 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp31_ = ro;
#line 351 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp32_ = gee_iterable_iterator ((GeeIterable*) _tmp31_);
#line 351 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	iter = _tmp32_;
#line 352 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp33_ = iter;
#line 352 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp34_ = gee_iterator_get_read_only (_tmp33_);
#line 352 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp35_ = _tmp34_;
#line 352 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp35_, "iter.read_only");
#line 353 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data3_->u = (guint) 0;
#line 354 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp36_ = iter;
#line 354 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp36_, ___lambda16__gee_forall_func, _data3_);
#line 360 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp37_ = _data3_->u;
#line 360 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp37_ == ((guint) 23), "u == 23");
#line 363 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp38_ = use_hash;
#line 363 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (!_tmp38_) {
#line 2880 "small-set.c"
		GeeSet* ro2 = NULL;
		GeeSet* _tmp39_ = NULL;
		GeeSet* _tmp40_ = NULL;
		GeeSet* _tmp41_ = NULL;
		GeeSet* _tmp42_ = NULL;
		GeeSet* _tmp43_ = NULL;
		GeeSet* _tmp44_ = NULL;
		GeeSet* _tmp45_ = NULL;
		GeeSet* _tmp46_ = NULL;
		GeeSet* _tmp47_ = NULL;
		GeeSet* _tmp48_ = NULL;
#line 366 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp39_ = objects;
#line 366 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp40_ = gee_set_get_read_only_view (_tmp39_);
#line 366 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp41_ = _tmp40_;
#line 366 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		ro2 = _tmp41_;
#line 367 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp42_ = ro;
#line 367 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp43_ = ro2;
#line 367 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_vala_assert (_tmp42_ != _tmp43_, "ro != ro2");
#line 370 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp44_ = ro;
#line 370 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp45_ = gee_set_get_read_only_view (_tmp44_);
#line 370 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp46_ = _tmp45_;
#line 370 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (ro2);
#line 370 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		ro2 = _tmp46_;
#line 371 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp47_ = ro;
#line 371 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp48_ = ro2;
#line 371 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_vala_assert (_tmp47_ == _tmp48_, "ro == ro2");
#line 363 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (ro2);
#line 2924 "small-set.c"
	}
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (iter);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (ro);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (objects);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	block3_data_unref (_data3_);
#line 325 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data3_ = NULL;
#line 2940 "small-set.c"
}


void small_set_tests_test_direct (SmallSetTests* self, gboolean use_hash) {
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GeeSet* objects = NULL;
	GeeSet* _tmp6_ = NULL;
	GeeSet* _tmp7_ = NULL;
	GeeSet* _tmp8_ = NULL;
	DirectEq* _tmp9_ = NULL;
	DirectEq* _tmp10_ = NULL;
	GeeSet* _tmp11_ = NULL;
	DirectEq* _tmp12_ = NULL;
	DirectEq* _tmp13_ = NULL;
	DirectEq* fortytwo = NULL;
	DirectEq* _tmp14_ = NULL;
	GeeSet* _tmp15_ = NULL;
	DirectEq* _tmp16_ = NULL;
	GeeSet* _tmp17_ = NULL;
	DirectEq* _tmp18_ = NULL;
	GeeSet* _tmp19_ = NULL;
	gint _tmp20_ = 0;
	gint _tmp21_ = 0;
	guint sum = 0U;
	guint _tmp31_ = 0U;
#line 375 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 377 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_DIRECT_EQ, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 377 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 378 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = gee_hash_set_new (TYPE_DIRECT_EQ, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 378 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	hash = _tmp1_;
#line 380 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp3_ = use_hash;
#line 380 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp3_) {
#line 2985 "small-set.c"
		GeeHashSet* _tmp4_ = NULL;
#line 381 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp4_ = hash;
#line 381 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GEE_TYPE_SET) ? ((GeeSet*) _tmp4_) : NULL;
#line 2991 "small-set.c"
	} else {
		FolksSmallSet* _tmp5_ = NULL;
#line 381 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp5_ = small;
#line 381 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GEE_TYPE_SET) ? ((GeeSet*) _tmp5_) : NULL;
#line 2998 "small-set.c"
	}
#line 380 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp6_ = _tmp2_;
#line 380 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 380 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	objects = _tmp7_;
#line 383 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp8_ = objects;
#line 383 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp9_ = direct_eq_new ((guint) 23);
#line 383 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp10_ = _tmp9_;
#line 383 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp8_, _tmp10_);
#line 383 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp10_);
#line 384 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp11_ = objects;
#line 384 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp12_ = direct_eq_new ((guint) 23);
#line 384 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp13_ = _tmp12_;
#line 384 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp11_, _tmp13_);
#line 384 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp13_);
#line 385 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp14_ = direct_eq_new ((guint) 42);
#line 385 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	fortytwo = _tmp14_;
#line 386 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp15_ = objects;
#line 386 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp16_ = fortytwo;
#line 386 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp15_, _tmp16_);
#line 387 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp17_ = objects;
#line 387 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp18_ = fortytwo;
#line 387 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) _tmp17_, _tmp18_);
#line 388 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp19_ = objects;
#line 388 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp20_ = gee_collection_get_size ((GeeCollection*) _tmp19_);
#line 388 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp21_ = _tmp20_;
#line 388 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp21_ == 3, "objects.size == 3");
#line 390 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	sum = (guint) 0;
#line 3052 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp22_ = NULL;
		GeeIterator* _tmp23_ = NULL;
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp22_ = objects;
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_it = _tmp23_;
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 3065 "small-set.c"
			GeeIterator* _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
			DirectEq* obj = NULL;
			GeeIterator* _tmp26_ = NULL;
			gpointer _tmp27_ = NULL;
			guint _tmp28_ = 0U;
			DirectEq* _tmp29_ = NULL;
			guint _tmp30_ = 0U;
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp24_ = _obj_it;
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp25_ = gee_iterator_next (_tmp24_);
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			if (!_tmp25_) {
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
				break;
#line 3082 "small-set.c"
			}
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp26_ = _obj_it;
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp27_ = gee_iterator_get (_tmp26_);
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			obj = (DirectEq*) _tmp27_;
#line 392 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp28_ = sum;
#line 392 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp29_ = obj;
#line 392 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp30_ = _tmp29_->u;
#line 392 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			sum = _tmp28_ + _tmp30_;
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 3100 "small-set.c"
		}
#line 391 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 3104 "small-set.c"
	}
#line 393 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp31_ = sum;
#line 393 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp31_ == ((guint) ((23 + 23) + 42)), "sum == 23 + 23 + 42");
#line 375 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (fortytwo);
#line 375 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (objects);
#line 375 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 375 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 3118 "small-set.c"
}


void small_set_tests_test_strings (SmallSetTests* self, gboolean use_hash) {
	FolksSmallSet* small = NULL;
	FolksSmallSet* _tmp0_ = NULL;
	GeeHashSet* hash = NULL;
	GHashFunc _tmp1_ = NULL;
	GEqualFunc _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GeeSet* strings = NULL;
	GeeSet* _tmp8_ = NULL;
	GeeSet* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
#line 396 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 398 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 398 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small = _tmp0_;
#line 399 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = g_str_hash;
#line 399 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = g_str_equal;
#line 399 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp3_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, (GeeHashDataFunc) _tmp1_, NULL, NULL, (GeeEqualDataFunc) _tmp2_, NULL, NULL);
#line 399 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	hash = _tmp3_;
#line 402 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp5_ = use_hash;
#line 402 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (_tmp5_) {
#line 3154 "small-set.c"
		GeeHashSet* _tmp6_ = NULL;
#line 403 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp6_ = hash;
#line 403 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GEE_TYPE_SET) ? ((GeeSet*) _tmp6_) : NULL;
#line 3160 "small-set.c"
	} else {
		FolksSmallSet* _tmp7_ = NULL;
#line 403 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp7_ = small;
#line 403 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GEE_TYPE_SET) ? ((GeeSet*) _tmp7_) : NULL;
#line 3167 "small-set.c"
	}
#line 402 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp8_ = _tmp4_;
#line 402 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 402 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	strings = _tmp9_;
#line 405 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) strings, "cheese");
#line 406 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) strings, "cheese");
#line 407 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_collection_add ((GeeCollection*) strings, "ham");
#line 408 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp10_ = gee_collection_get_size ((GeeCollection*) strings);
#line 408 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp11_ = _tmp10_;
#line 408 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp11_ == 2, "strings.size == 2");
#line 396 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (strings);
#line 396 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (hash);
#line 396 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (small);
#line 3193 "small-set.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return _data4_;
#line 3202 "small-set.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 3211 "small-set.c"
		SmallSetTests * self;
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		self = _data4_->self;
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_data4_->small);
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (self);
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		g_slice_free (Block4Data, _data4_);
#line 3221 "small-set.c"
	}
}


static gboolean __lambda22_ (Block4Data* _data4_, UInt* obj) {
	SmallSetTests * self;
	gboolean result = FALSE;
	FolksSmallSet* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gconstpointer _tmp2_ = NULL;
	UInt* _tmp3_ = NULL;
	gint _tmp4_ = 0;
#line 423 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	self = _data4_->self;
#line 423 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_val_if_fail (obj != NULL, FALSE);
#line 426 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = _data4_->small;
#line 426 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = _data4_->i;
#line 426 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = folks_small_set_get (_tmp0_, _tmp1_);
#line 426 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp3_ = obj;
#line 426 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (((UInt*) _tmp2_) == _tmp3_, "small[i] == obj");
#line 427 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp4_ = _data4_->i;
#line 427 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data4_->i = _tmp4_ + 1;
#line 428 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = TRUE;
#line 428 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (obj);
#line 428 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 3258 "small-set.c"
}


static gboolean ___lambda22__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = __lambda22_ (self, g);
#line 423 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 3267 "small-set.c"
}


void small_set_tests_test_cheating (SmallSetTests* self) {
	Block4Data* _data4_;
	FolksSmallSet* _tmp0_ = NULL;
	GeeSet* set_ = NULL;
	FolksSmallSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	FolksSmallSet* _tmp3_ = NULL;
	UInt* _tmp4_ = NULL;
	UInt* _tmp5_ = NULL;
	FolksSmallSet* _tmp6_ = NULL;
	UInt* _tmp7_ = NULL;
	UInt* _tmp8_ = NULL;
	FolksSmallSet* _tmp9_ = NULL;
	UInt* _tmp10_ = NULL;
	UInt* _tmp11_ = NULL;
	FolksSmallSet* _tmp12_ = NULL;
	UInt* _tmp13_ = NULL;
	UInt* _tmp14_ = NULL;
	FolksSmallSet* _tmp15_ = NULL;
	UInt* _tmp16_ = NULL;
	UInt* _tmp17_ = NULL;
	GeeSet* _tmp18_ = NULL;
	GeeIterator* _tmp19_ = NULL;
	GeeIterator* _tmp20_ = NULL;
	gint _tmp21_ = 0;
	guint sum = 0U;
	guint _tmp31_ = 0U;
	guint _tmp46_ = 0U;
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_return_if_fail (self != NULL);
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data4_->_ref_count_ = 1;
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data4_->self = g_object_ref (self);
#line 413 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = folks_small_set_new (TYPE_UINT, (GBoxedCopyFunc) g_object_ref, g_object_unref, _uint_hash_static_gee_hash_data_func, NULL, NULL, _uint_equals_static_gee_equal_data_func, NULL, NULL);
#line 413 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data4_->small = _tmp0_;
#line 414 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp1_ = _data4_->small;
#line 414 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GEE_TYPE_SET) ? ((GeeSet*) _tmp1_) : NULL, GEE_TYPE_SET, GeeSet));
#line 414 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	set_ = _tmp2_;
#line 416 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp3_ = _data4_->small;
#line 416 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp4_ = uint_new ((guint) 1);
#line 416 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp5_ = _tmp4_;
#line 416 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, _tmp5_);
#line 416 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp5_);
#line 417 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp6_ = _data4_->small;
#line 417 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp7_ = uint_new ((guint) 10);
#line 417 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp8_ = _tmp7_;
#line 417 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp6_, _tmp8_);
#line 417 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp8_);
#line 418 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp9_ = _data4_->small;
#line 418 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp10_ = uint_new ((guint) 100);
#line 418 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp11_ = _tmp10_;
#line 418 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, _tmp11_);
#line 418 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp11_);
#line 419 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp12_ = _data4_->small;
#line 419 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp13_ = uint_new ((guint) 1000);
#line 419 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp14_ = _tmp13_;
#line 419 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp12_, _tmp14_);
#line 419 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp14_);
#line 420 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp15_ = _data4_->small;
#line 420 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp16_ = uint_new ((guint) 10000);
#line 420 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp17_ = _tmp16_;
#line 420 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, _tmp17_);
#line 420 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp17_);
#line 422 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data4_->i = 0;
#line 423 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp18_ = set_;
#line 423 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
#line 423 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp20_ = _tmp19_;
#line 423 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	gee_traversable_foreach ((GeeTraversable*) _tmp20_, ___lambda22__gee_forall_func, _data4_);
#line 423 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (_tmp20_);
#line 430 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp21_ = _data4_->i;
#line 430 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp21_ == 5, "i == 5");
#line 434 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	sum = (guint) 0;
#line 3385 "small-set.c"
	{
		GeeIterator* _obj_it = NULL;
		GeeSet* _tmp22_ = NULL;
		GeeIterator* _tmp23_ = NULL;
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp22_ = set_;
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_it = _tmp23_;
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 3398 "small-set.c"
			GeeIterator* _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
			UInt* obj = NULL;
			GeeIterator* _tmp26_ = NULL;
			gpointer _tmp27_ = NULL;
			guint _tmp28_ = 0U;
			UInt* _tmp29_ = NULL;
			guint _tmp30_ = 0U;
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp24_ = _obj_it;
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp25_ = gee_iterator_next (_tmp24_);
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			if (!_tmp25_) {
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
				break;
#line 3415 "small-set.c"
			}
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp26_ = _obj_it;
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp27_ = gee_iterator_get (_tmp26_);
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp27_;
#line 436 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp28_ = sum;
#line 436 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp29_ = obj;
#line 436 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp30_ = _tmp29_->u;
#line 436 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			sum = _tmp28_ + _tmp30_;
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_g_object_unref0 (obj);
#line 3433 "small-set.c"
		}
#line 435 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_it);
#line 3437 "small-set.c"
	}
#line 437 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp31_ = sum;
#line 437 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp31_ == ((guint) 11111), "sum == 11111");
#line 441 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	sum = (guint) 0;
#line 3445 "small-set.c"
	{
		FolksSmallSet* _obj_list = NULL;
		FolksSmallSet* _tmp32_ = NULL;
		FolksSmallSet* _tmp33_ = NULL;
		gint _obj_size = 0;
		FolksSmallSet* _tmp34_ = NULL;
		gint _tmp35_ = 0;
		gint _tmp36_ = 0;
		gint _obj_index = 0;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp32_ = _data4_->small;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp33_ = _g_object_ref0 (_tmp32_);
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_list = _tmp33_;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp34_ = _obj_list;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp35_ = gee_collection_get_size ((GeeCollection*) _tmp34_);
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_tmp36_ = _tmp35_;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_size = _tmp36_;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_obj_index = -1;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		while (TRUE) {
#line 3473 "small-set.c"
			gint _tmp37_ = 0;
			gint _tmp38_ = 0;
			gint _tmp39_ = 0;
			UInt* obj = NULL;
			FolksSmallSet* _tmp40_ = NULL;
			gint _tmp41_ = 0;
			gconstpointer _tmp42_ = NULL;
			guint _tmp43_ = 0U;
			UInt* _tmp44_ = NULL;
			guint _tmp45_ = 0U;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp37_ = _obj_index;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_obj_index = _tmp37_ + 1;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp38_ = _obj_index;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp39_ = _obj_size;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			if (!(_tmp38_ < _tmp39_)) {
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
				break;
#line 3496 "small-set.c"
			}
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp40_ = _obj_list;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp41_ = _obj_index;
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp42_ = folks_small_set_get (_tmp40_, _tmp41_);
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			obj = (UInt*) _tmp42_;
#line 443 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp43_ = sum;
#line 443 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp44_ = obj;
#line 443 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			_tmp45_ = _tmp44_->u;
#line 443 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
			sum = _tmp43_ + _tmp45_;
#line 3514 "small-set.c"
		}
#line 442 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
		_g_object_unref0 (_obj_list);
#line 3518 "small-set.c"
	}
#line 444 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp46_ = sum;
#line 444 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_vala_assert (_tmp46_ == ((guint) 11111), "sum == 11111");
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (set_);
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	block4_data_unref (_data4_);
#line 411 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_data4_ = NULL;
#line 3530 "small-set.c"
}


static void small_set_tests_class_init (SmallSetTestsClass * klass) {
#line 56 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	small_set_tests_parent_class = g_type_class_peek_parent (klass);
#line 3537 "small-set.c"
}


static void small_set_tests_instance_init (SmallSetTests * self) {
}


GType small_set_tests_get_type (void) {
	static volatile gsize small_set_tests_type_id__volatile = 0;
	if (g_once_init_enter (&small_set_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SmallSetTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) small_set_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SmallSetTests), 0, (GInstanceInitFunc) small_set_tests_instance_init, NULL };
		GType small_set_tests_type_id;
		small_set_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "SmallSetTests", &g_define_type_info, 0);
		g_once_init_leave (&small_set_tests_type_id__volatile, small_set_tests_type_id);
	}
	return small_set_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SmallSetTests* tests = NULL;
	SmallSetTests* _tmp0_ = NULL;
#line 450 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_test_init (&args_length1, &args, NULL);
#line 452 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_tmp0_ = small_set_tests_new ();
#line 452 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	tests = _tmp0_;
#line 453 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 454 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_test_run ();
#line 455 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 457 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	result = 0;
#line 457 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	_g_object_unref0 (tests);
#line 457 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return result;
#line 3579 "small-set.c"
}


int main (int argc, char ** argv) {
#line 448 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	g_type_init ();
#line 448 "/home/treitter/collabora/folks/tests/folks/small-set.vala"
	return _vala_main (argv, argc);
#line 3588 "small-set.c"
}



